Skip to contents

Get monthly activity and performance indicators by organisation.

Usage

get_activity_performance_monthly(periods = NULL, use_cache = TRUE)

Arguments

periods

Character vector, specifying periods (e.g., "2025-09", "2025-08"). If NULL (default), returns all available monthly periods

use_cache

Logical, specifying whether to use cached data if available. Default TRUE.

Value

Tibble with activity and performance data in long format

Examples

if (FALSE) { # \dontrun{
# Get all monthly periods
activity_df <- get_activity_performance_monthly()

# Get specific monthly periods
activity_df <- get_activity_performance_monthly(periods = c("2025-09", "2025-08"))

# Re-download to get the latest data version
activity_df <- get_activity_performance_monthly(use_cache = FALSE)
} # }