Combines the "Data measures (main)" and "Data measures (additional)" sheets released alongside the annual NHS Talking Therapies reports.
Arguments
- periods
Character vector, specifying periods (e.g., "2023-24", "2024-25"). If NULL (default), returns all available annual periods
- use_cache
Logical, specifying whether to use cached data if available. Default TRUE.
- version
Character, specifying a pinned data version (e.g., "0.1.0"). If NULL (default), the latest version is used. See
available_versions().
References
NHS England. NHS Talking Therapies for Anxiety and Depression Annual Reports