Get monthly metadata for NHS Talking Therapies measures
Source:R/get-monthly.R
get_metadata_monthly.RdGets the definitions, derivations, and construction notes for each reported measure.
Arguments
- periods
Character vector, specifying periods (e.g., "2025-09", "2025-08"). If NULL (default), returns all available monthly periods
- use_cache
Logical, specifying whether to use cached data if available. Default TRUE.
- version
Character, specifying a pinned data version (e.g., "0.3.0"). If NULL (default), the latest version is used. See
available_versions().
References
NHS England. NHS Talking Therapies Monthly Statistics Including Employment Advisors
NHS England. NHS Talking Therapies Monthly Statistics Including Employment Advisors: Metadata (monthly)
NHS England. NHS Talking Therapies Data Quality Note