Get annual key performance measures including referrals, assessments, treatment completions, recovery rates, and waiting times by organisation
References
NHS England. NHS Talking Therapies for Anxiety and Depression Annual Reports
Examples
if (FALSE) { # \dontrun{
# Get all annual periods
key_measures_df <- get_key_measures_annual()
# Get specific annual periods
key_measures_df <- get_key_measures_annual(periods = c("2023-24", "2024-25"))
# Re-download to get the latest data version
key_measures_df <- get_key_measures_annual(use_cache = FALSE)
} # }