Skip to contents

Gets the definitions, derivations, and construction notes for each reported measure.

Usage

get_metadata_monthly(periods = NULL, use_cache = TRUE)

Arguments

periods

Character vector, specifying periods (e.g., "2025-09", "2025-08"). If NULL (default), returns all available monthly periods

use_cache

Logical, specifying whether to use cached data if available. Default TRUE.

Value

Tibble with metadata for each measure

Examples

if (FALSE) { # \dontrun{
metadata <- get_metadata_monthly()
} # }