Get annual Patient Reported Outcome Measures (PROMs) mean and SD broken down by therapy type, problem descriptor, and providers.
References
NHS England. NHS Talking Therapies for Anxiety and Depression Annual Reports
Examples
if (FALSE) { # \dontrun{
# Get all annual periods
proms_df <- get_proms_annual()
# Get specific annual periods
proms_df <- get_proms_annual(periods = c("2023-24", "2024-25"))
# Re-download to get the latest data version
proms_df <- get_proms_annual(use_cache = FALSE)
} # }