Get position of therapy types within the referral pathways
Source:R/get-annual.R
get_therapy_position_annual.RdGet the number of courses of therapy by therapy type and position within the referral pathway. A course of therapy is a set of 2 or more attended treatment appointments where the same therapy type is recorded that occur within a referral pathway. Counts are based on referrals finishing a course of treatment in the year. Other low/high internsity and low/high employment support therapy types have been excluded from theses analyses.
References
NHS England. NHS Talking Therapies for Anxiety and Depression Annual Reports
Examples
if (FALSE) { # \dontrun{
# Get all annual periods
therapy_position_df <- get_therapy_position_annual()
# Get specific annual periods
therapy_position_df <- get_therapy_position_annual(periods = c("2023-24", "2024-25"))
# Re-download to get the latest data version
therapy_position_df <- get_therapy_position_annual(use_cache = FALSE)
} # }